@@ -1,4 +1,4 @@
-# Copyright (C) 2020  Brodie Gaslam
+# Copyright (C) 2021 Brodie Gaslam
 # 
 # This file is part of "unitizer"
 # 
@@ -36,7 +36,7 @@ NULL
   if(is.null(getOption('unitizer.state'))) {
     packageStartupMessage(
       "State tracking is disabled by default to comply with CRAN policies. ",
-      "Add `options(unitizer.state='recommended')` to your 'Rprofile' file ",
+      "Add `options(unitizer.state='suggested')` to your 'Rprofile' file ",
       "to enable, or `options(unitizer.state='off')` to quash this message ",
       "without enabling.  Prior to enabling, be sure to read `?unitizerState`,",
       "in particular the 'CRAN non-compliance' section."
